@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -28,6 +24,7 @@ short_description = _('DHCP: Service')
 object_name = _('DHCP service')
 object_name_plural = _('DHCP services')
 long_description = _('The top-level container for a DHCP configuration.')
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -57,6 +54,7 @@ layout = [
 
 mapping = univention.admin.mapping.mapping()
 mapping.register('service', 'cn', None, univention.admin.mapping.ListToString)
+# fmt: on
 
 add_dhcp_options(__name__)
 
@@ -84,12 +82,11 @@ class object(DHCPBase):
                 univention.admin.filter.expression('objectClass', 'dhcpService'),
                 univention.admin.filter.expression('objectClass', 'univentionDhcpService'),
             ]),
-        ])
+        ])  # fmt: skip
 
 
 def identify(dn: str, attr: univention.admin.handlers._Attributes) -> bool:
-    return b'dhcpService' in attr.get('objectClass', []) \
-        or b'univentionDhcpService' in attr.get('objectClass', [])
+    return b'dhcpService' in attr.get('objectClass', []) or b'univentionDhcpService' in attr.get('objectClass', [])
 
 
 lookup_filter = object.lookup_filter
