@@ -348,70 +348,67 @@ class object(univention.admin.handlers.simpleLdap):
 
             self.save()
 
-    def fast_member_add(self, memberdnlist, uidlist):
+    def fast_member_add(self, memberdnlist, uidlist) -> bool:
+        """
+        Make groups membership changes in a slow(!) way.
+
+        .. deprecated:: 5.2-4
+        """
+        # actually this is very slow_member_add(). Don't use it. Only used by AD/S4-Connector.
         ml = []
         uids = set()
         members = set()
         searchResult = self.lo.authz_connection.get(self.dn, attr=['uniqueMember', 'memberUid'])
         if searchResult:
             uids = {x.decode('UTF-8').lower() for x in searchResult.get('memberUid', [])}
-            members = {x.decode('UTF-8').lower() for x in searchResult.get('uniqueMember', [])}
+            members = DN.set(x.decode('UTF-8') for x in searchResult.get('uniqueMember', []))
 
         add_uidlist = [uid for uid in uidlist if uid.lower() not in uids]
         if add_uidlist:
             ml.append(('memberUid', b'', [x.encode('UTF-8') for x in add_uidlist]))
 
-        add_memberdnlist = [dn for dn in memberdnlist if dn.lower() not in members]
-
+        add_memberdnlist = DN.set(memberdnlist) - members
         if add_memberdnlist:
-            ml.append(('uniqueMember', b'', [x.encode('UTF-8') for x in add_memberdnlist]))
+            ml.append(('uniqueMember', b'', [str(x).encode('UTF-8') for x in add_memberdnlist]))
 
         if ml:
-            try:
-                return self.lo.authz_connection.modify(self.dn, ml)
-            except ldap.NO_SUCH_OBJECT:
-                raise univention.admin.uexceptions.noObject(self.dn)
-            except ldap.INSUFFICIENT_ACCESS:
-                raise univention.admin.uexceptions.permissionDenied()
-            except ldap.LDAPError as msg:
-                raise univention.admin.uexceptions.ldapError(msg.args[0]['desc'])
+            return self.lo.authz_connection.modify(self.dn, ml)
 
         # return True if object has been modified
         return bool(ml)
 
-    def fast_member_remove(self, memberdnlist, uidlist, ignore_license=False, _retry_on_attribute_error=True):
+    def fast_member_remove(self, memberdnlist, uidlist, ignore_license=False, _retry_on_attribute_error=True) -> bool:
+        """
+        Make groups membership changes in a slow(!) way.
+
+        .. deprecated:: 5.2-4
+        """
+        # actually this is very slow_member_remove(). Don't use it. Only used by AD/S4-Connector.
         ml = []
         uids = {}
         members = set()
         searchResult = self.lo.authz_connection.get(self.dn, attr=['uniqueMember', 'memberUid'])
         if searchResult:
             uids = {x.decode('UTF-8').lower(): x.decode('UTF-8') for x in searchResult.get('memberUid', [])}
-            members = {x.decode('UTF-8').lower() for x in searchResult.get('uniqueMember', [])}
+            members = DN.set(x.decode('UTF-8') for x in searchResult.get('uniqueMember', []))
 
         remove_uidlist = [uids[uid.lower()] for uid in uidlist if uid.lower() in uids]
         if remove_uidlist:
             ml.append(('memberUid', [x.encode('UTF-8') for x in remove_uidlist], b''))
 
-        remove_memberdnlist = [dn for dn in memberdnlist if dn.lower() in members]
+        remove_memberdnlist = DN.set(memberdnlist) & members
         if remove_memberdnlist:
-            ml.append(('uniqueMember', [x.encode('UTF-8') for x in remove_memberdnlist], b''))
+            ml.append(('uniqueMember', [str(x).encode('UTF-8') for x in remove_memberdnlist], b''))
 
         if ml:
             try:
-                try:
-                    return self.lo.authz_connection.modify(self.dn, ml, exceptions=True, ignore_license=ignore_license)
-                except ldap.NO_SUCH_ATTRIBUTE:
-                    # maybe this is the refint overlay:
-                    # uniqueMember has already been removed. lets try again, probably with just memberUid...
-                    if not _retry_on_attribute_error:
-                        raise
-                    return self.fast_member_remove(memberdnlist, uidlist, ignore_license=ignore_license, _retry_on_attribute_error=False)
-            except ldap.NO_SUCH_OBJECT:
-                raise univention.admin.uexceptions.noObject(self.dn)
-            except ldap.INSUFFICIENT_ACCESS:
-                raise univention.admin.uexceptions.permissionDenied()
-            except ldap.LDAPError as msg:
-                raise univention.admin.uexceptions.ldapError(msg.args[0]['desc'])
+                return self.lo.authz_connection.modify(self.dn, ml, ignore_license=ignore_license)
+            except univention.admin.uexceptions.ldapError as exc:
+                if not _retry_on_attribute_error or not isinstance(exc.original_exception, ldap.NO_SUCH_ATTRIBUTE):
+                    raise
+                # maybe this is the refint overlay:
+                # uniqueMember has already been removed. lets try again, probably with just memberUid...
+                return self.fast_member_remove(memberdnlist, uidlist, ignore_license=ignore_license, _retry_on_attribute_error=False)
 
         # return True if object has been modified
         return bool(ml)
