@@ -6,11 +6,7 @@
 from __future__ import annotations
 
 import univention.admin
-import univention.admin.filter
 import univention.admin.handlers
-import univention.admin.handlers.mail.domain
-import univention.admin.handlers.mail.folder
-import univention.admin.handlers.mail.lists
 import univention.admin.localization
 import univention.admin.uldap
 from univention.admin.layout import Tab
