@@ -4,7 +4,6 @@
 """|UDM| module for network objects"""
 
 import ipaddress
-from logging import getLogger
 
 import ldap
 from ldap.filter import filter_format
@@ -17,7 +16,6 @@ import univention.admin.uexceptions
 from univention.admin.layout import Group, Tab
 
 
-log = getLogger('ADMIN')
 translation = univention.admin.localization.translation('univention.admin.handlers.networks')
 _ = translation.translate
 
@@ -201,7 +199,7 @@ class object(univention.admin.handlers.simpleLdap):
             try:
                 self.lo.authz_connection.modify(computer.dn, [('univentionNetworkLink', self.dn.encode('UTF-8'), b'')])
             except (univention.admin.uexceptions.base, ldap.LDAPError):
-                log.exception('Failed to remove network %s from %s:', self.dn, computer.dn)
+                self.log.exception('Failed to remove network from computer', dn=self.dn, computer=computer.dn)
 
     def _ldap_addlist(self):
         if not self['nextIp']:
@@ -250,7 +248,7 @@ class object(univention.admin.handlers.simpleLdap):
                     raise univention.admin.uexceptions.rangeInBroadcastAddress('%s-%s' % (firstIP, lastIP))
                 ipRange.append(' '.join(i).encode('ASCII'))
 
-            log.debug('old Range: %s', self.oldinfo.get('ipRange'))
+            self.log.debug('old Range: %s', self.oldinfo.get('ipRange'))
             ml = [x for x in ml if x[0] != 'univentionIpRange']
             ml.append(('univentionIpRange', self.oldattr.get('univentionIpRange', [b'']), ipRange))
 
