@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -34,7 +30,7 @@ operations = ['add', 'edit', 'remove', 'search']
 
 policy_oc = 'univentionPolicyAdminContainerSettings'
 policy_apply_to = []
-policy_position_dn_prefix = "cn=container,cn=admin"
+policy_position_dn_prefix = 'cn=container,cn=admin'
 
 childs = False
 short_description = _('Policy: Univention Directory Manager container settings')
@@ -42,6 +38,7 @@ object_name = _('Univention Directory Manager container settings policy')
 object_name_plural = _('Univention Directory Manager container settings policies')
 policy_short_description = _('Univention Directory Manager container settings')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -87,6 +84,7 @@ mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('listModules', 'univentionAdminListModules')
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
