@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -32,8 +28,8 @@ module = 'policies/printserver'
 operations = ['add', 'edit', 'remove', 'search']
 
 policy_oc = 'univentionPolicyPrintServer'
-policy_apply_to = ["computers/memberserver", "computers/domaincontroller_backup", "computers/domaincontroller_master", "computers/domaincontroller_slave"]
-policy_position_dn_prefix = "cn=printservers"
+policy_apply_to = ['computers/memberserver', 'computers/domaincontroller_backup', 'computers/domaincontroller_master', 'computers/domaincontroller_slave']
+policy_position_dn_prefix = 'cn=printservers'
 
 childs = False
 short_description = _('Policy: Print server')
@@ -41,6 +37,7 @@ object_name = _('Print server policy')
 object_name_plural = _('Print server policies')
 policy_short_description = _('Print server')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -87,6 +84,7 @@ mapping = univention.admin.mapping.mapping()
 mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('printServer', 'univentionPrintServer', None, univention.admin.mapping.ListToString)
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
