@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -33,8 +29,8 @@ module = 'policies/release'
 operations = ['add', 'edit', 'remove', 'search']
 
 policy_oc = 'univentionPolicyUpdate'
-policy_apply_to = ["computers/domaincontroller_master", "computers/domaincontroller_backup", "computers/domaincontroller_slave", "computers/memberserver"]
-policy_position_dn_prefix = "cn=update"
+policy_apply_to = ['computers/domaincontroller_master', 'computers/domaincontroller_backup', 'computers/domaincontroller_slave', 'computers/memberserver']
+policy_position_dn_prefix = 'cn=update'
 
 childs = False
 short_description = _('Policy: Automatic updates')
@@ -42,6 +38,7 @@ object_name = _('Automatic updates policy')
 object_name_plural = _('Automatic updates policies')
 policy_short_description = _('Automatic updates')
 long_description = ''
+# fmt: off
 options = {
     'default': univention.admin.option(
         short_description=short_description,
@@ -94,6 +91,7 @@ mapping.register('name', 'cn', None, univention.admin.mapping.ListToString)
 mapping.register('releaseVersion', 'univentionUpdateVersion', None, univention.admin.mapping.ListToString)
 mapping.register('activate', 'univentionUpdateActivate', None, univention.admin.mapping.ListToString)
 register_policy_mapping(mapping)
+# fmt: on
 
 
 class object(univention.admin.handlers.simplePolicy):
