@@ -1,4 +1,4 @@
 # SPDX-FileCopyrightText: 2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
-"""Recyclebin handlers package"""
+"""Recycle Bin handlers package"""
