@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -80,7 +76,24 @@ class object(univention.admin.handlers.users.user.object):
         response: dict | None = None,
     ) -> list[univention.admin.handlers.simpleLdap]:
         dn = lo.whoami()
-        return [user for user in udm_user.lookup(co, lo, filter_s, base, superordinate, scope=scope, unique=unique, required=required, timeout=timeout, sizelimit=sizelimit, serverctrls=serverctrls, response=response) if lo.compare_dn(dn, user.dn)]
+        return [
+            user
+            for user in udm_user.lookup(
+                co,
+                lo,
+                filter_s,
+                base,
+                superordinate,
+                scope=scope,
+                unique=unique,
+                required=required,
+                timeout=timeout,
+                sizelimit=sizelimit,
+                serverctrls=serverctrls,
+                response=response,
+            )
+            if lo.compare_dn(dn, user.dn)
+        ]
 
     @classmethod
     def identify(cls, dn: str, attr: univention.admin.handlers._Attributes, canonical: bool = False) -> bool:
