@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2004-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -46,6 +42,7 @@ class Attributes:
 def moreGroupware(license):
     return False, (license.compare(license.licenses[license.ACCOUNT], license.licenses[license.GROUPWARE]) != 1)
 
+
 # Examples:
 #    'computers/ipmanagedclient': Attributes( UCS + [ 'OEM1'] ),
 #    'computers/domaincontroller_master': Attributes( UCS + ['OEM2'] ,options =
@@ -56,5 +53,4 @@ def moreGroupware(license):
 #                } ),
 
 
-modules = {
-}
+modules = {}
