@@ -1,7 +1,3 @@
-#
-# Like what you see? Join us!
-# https://www.univention.com/about-us/careers/vacancies/
-#
 # SPDX-FileCopyrightText: 2015-2025 Univention GmbH
 # SPDX-License-Identifier: AGPL-3.0-only
 
@@ -34,15 +30,15 @@ def policy_object_tab() -> Tab:
         ['ldapFilter'],
         ['requiredObjectClasses', 'prohibitedObjectClasses'],
         ['fixedAttributes', 'emptyAttributes'],
-    ])
+    ])  # fmt: skip
 
 
 def requiredObjectClassesProperty(**kwargs: Any) -> tuple[str, univention.admin.property]:
     pargs = {
-        "short_description": _('Required object class'),
-        "long_description": '',
-        "syntax": univention.admin.syntax.ldapObjectClass,
-        "multivalue": True,
+        'short_description': _('Required object class'),
+        'long_description': '',
+        'syntax': univention.admin.syntax.ldapObjectClass,
+        'multivalue': True,
     }
     pargs.update(kwargs)
     return 'requiredObjectClasses', univention.admin.property(**pargs)
@@ -50,10 +46,10 @@ def requiredObjectClassesProperty(**kwargs: Any) -> tuple[str, univention.admin.
 
 def prohibitedObjectClassesProperty(**kwargs: Any) -> tuple[str, univention.admin.property]:
     pargs = {
-        "short_description": _('Excluded object class'),
-        "long_description": '',
-        "syntax": univention.admin.syntax.ldapObjectClass,
-        "multivalue": True,
+        'short_description': _('Excluded object class'),
+        'long_description': '',
+        'syntax': univention.admin.syntax.ldapObjectClass,
+        'multivalue': True,
     }
     pargs.update(kwargs)
     return 'prohibitedObjectClasses', univention.admin.property(**pargs)
@@ -61,9 +57,9 @@ def prohibitedObjectClassesProperty(**kwargs: Any) -> tuple[str, univention.admi
 
 def fixedAttributesProperty(**kwargs: Any) -> tuple[str, univention.admin.property]:
     pargs = {
-        "short_description": _('Fixed attribute'),
-        "long_description": '',
-        "multivalue": True,
+        'short_description': _('Fixed attribute'),
+        'long_description': '',
+        'multivalue': True,
     }
     pargs.update(kwargs)
     return 'fixedAttributes', univention.admin.property(**pargs)
@@ -71,9 +67,9 @@ def fixedAttributesProperty(**kwargs: Any) -> tuple[str, univention.admin.proper
 
 def emptyAttributesProperty(**kwargs: Any) -> tuple[str, univention.admin.property]:
     pargs = {
-        "short_description": _('Empty attribute'),
-        "long_description": '',
-        "multivalue": True,
+        'short_description': _('Empty attribute'),
+        'long_description': '',
+        'multivalue': True,
     }
     pargs.update(kwargs)
     return 'emptyAttributes', univention.admin.property(**pargs)
@@ -81,9 +77,9 @@ def emptyAttributesProperty(**kwargs: Any) -> tuple[str, univention.admin.proper
 
 def ldapFilterProperty(**kwargs: Any) -> tuple[str, univention.admin.property]:
     pargs = {
-        "short_description": _('LDAP filter'),
-        "long_description": _('This policy applies only to objects which matches this LDAP filter.'),
-        "syntax": univention.admin.syntax.ldapFilter,
+        'short_description': _('LDAP filter'),
+        'long_description': _('This policy applies only to objects which matches this LDAP filter.'),
+        'syntax': univention.admin.syntax.ldapFilter,
     }
     pargs.update(kwargs)
     return 'ldapFilter', univention.admin.property(**pargs)
