@@ -762,7 +762,7 @@ class access:
     def filter_lookup_results(self, results, context=None):
         """Evaluate access control rules for filtering of results"""
         # TODO: check if we are allowed at all to search in the base, with the scope and the given filter for the attrs
-        return self.authz.filter_search_results(self, results)
+        return self.authz.filter_search_results(self, results, context=context)
 
     def search_filtered(self, context, filter='(objectClass=*)', base='', *args, **kwargs):
         if not self._verify_search_base(base) or not self._verify_search_filter(filter):
@@ -782,7 +782,7 @@ class access:
 
     def _filter_ldap_search_dns(self, results, context=None):
         """Evaluate access control rules for filtering of results"""
-        return self.authz.filter_search_results_dn(self, results)
+        return self.authz.filter_search_results_dn(self, results, context=context)
 
     def _verify_search_base(self, base):
         # mimic ldapsearch behavior
