@@ -4,9 +4,6 @@
 
 """This tool changes the priority from some SRV records from 0 to 100"""
 
-import univention.admin
-import univention.admin.handlers.dns.forward_zone
-import univention.admin.handlers.dns.srv_record
 import univention.admin.modules
 import univention.admin.uldap
 import univention.config_registry
@@ -25,8 +22,7 @@ SRV_RECORDS = [
 ]
 
 
-def main():
-    # type: () -> None
+def main() -> None:
     univention.admin.modules.update()
 
     configRegistry = univention.config_registry.ConfigRegistry()
